# Changelog

## [v0.1.0](https://github.com/sci-oer/student-cli/releases/v0.1.0) (2022-08-01)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/v0.0.1...v0.1.0)

**Implemented enhancements:**

- Release to PyPi [\#1](https://github.com/sci-oer/student-cli/issues/1)

**Merged pull requests:**

- Update dependency pytest to v7.1.2 [\#19](https://github.com/sci-oer/student-cli/pull/19) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency pyparsing to v3.0.9 [\#18](https://github.com/sci-oer/student-cli/pull/18) ([renovate[bot]](https://github.com/apps/renovate))
- fix: missing dependancies in the test pipeline [\#17](https://github.com/sci-oer/student-cli/pull/17) ([MarshallAsch](https://github.com/MarshallAsch))
- Update dependency platformdirs to v2.5.2 [\#15](https://github.com/sci-oer/student-cli/pull/15) ([renovate[bot]](https://github.com/apps/renovate))
- Update dependency click to v8.1.3 [\#14](https://github.com/sci-oer/student-cli/pull/14) ([renovate[bot]](https://github.com/apps/renovate))
- feat: add pipline to automaticly create and release a new version [\#13](https://github.com/sci-oer/student-cli/pull/13) ([MarshallAsch](https://github.com/MarshallAsch))
- feat: add inital manifest file to prevent too many files from being included [\#12](https://github.com/sci-oer/student-cli/pull/12) ([MarshallAsch](https://github.com/MarshallAsch))
- fix: remove incorrectly commited application config file [\#11](https://github.com/sci-oer/student-cli/pull/11) ([MarshallAsch](https://github.com/MarshallAsch))
- Configure Renovate [\#7](https://github.com/sci-oer/student-cli/pull/7) ([renovate[bot]](https://github.com/apps/renovate))

## [v0.0.1](https://github.com/sci-oer/student-cli/releases/v0.0.1) (2022-04-04)

[Full Changelog](https://github.com/sci-oer/student-cli/compare/d0de775a4608f1aeecebf963071d5bbbb77b3c3f...v0.0.1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
